@@ -1083,3 +1083,12 @@ read.org.table <- function(file, header = TRUE, skip = 0,
     read.table(f.ll, header=FALSE, sep = "|",
                col.names = col.names, nrows=nrows, ...) # , encoding = "UTF-8" *not* good
 }
+
+## as compact numeric format() as possible
+formatN <- function(x, digits = 1L, sci = c(-1L,-2L)) {
+    stopifnot(is.numeric(x) || is.complex(x), sci == as.integer(sci))
+    if(length(sci) == 1L) sci <- c(sci,sci)
+    sub("e-0*", "e-",
+        sub("e\\+0*","e",
+            vapply(x, function(u) format(u, digits=1, scientific = sci[if(abs(u) < 1) 1 else 2]), "")))
+}
